package App::Bin4TSV ;  
our $VERSION = '0.340' ; 
our $DATE = '2021-05-28T02:55+09:00' ; 

=encoding utf8

=head1 NAME

App::Bin4TSV

=head1 SYNOPSIS

This module provides dozens of useful Unix-like commands to handle tabular text files especially TSV files.

=head1 DESCRIPTION

The included commands are as follows. 

B<alluniq>

B<backcolor>

B<boxmuller>

B<cat-n>

B<chars2code>

B<cointoss>

B<colchop>

B<colgrep>

B<colhashS>

B<collen>

B<colorplus>

B<colpairs>

B<colsplit>

B<colsummary>

B<crosstable>

B<csel>

B<csv2tsv>

B<depthdepth>

B<digitdemog>

B<dirdig>

B<dirdim>

B<dirhier>

B<entrolines>

B<expskip>

B<fileday>

B<freq>

B<gzpaste>

B<hashtotal>

B<headomit>

B<horsekicks>

B<idmaker>

B<inarow>

B<join2>

B<joinn>

B<keyvalues>

B<kvcmp>

B<lastaccess>

B<linedigest>

B<lminusl>

B<madeafter>

B<mtranspose>

B<quantile>

B<resistorcc>

B<saikoro>

B<samesize>

B<sampler>

B<summing>

B<t1generate>

B<t2generate>

B<timeput>

B<uniq-c>

B<updir>

B<venn>

B<wc-l>

B<xlsx2tsv>



=head1 SEE ALSO

=cut

1 ;
